@@ -1,18 +1,6 @@
 from typing import List, Tuple, Union
 import numpy as np
 
-_EPS = 1e-8
-
-
-def _times(a, b):
-    cnt = 0
-
-    while a - b > _EPS:
-        a -= b
-        cnt += 1
-    return cnt
-
-
 def hist(array: List[Union[int, float]],
               bins: int) -> Tuple[List[int], List[float]]:
     """
@@ -30,5 +18,5 @@ def hist(array: List[Union[int, float]],
 
     bins_val = [0] * len(bins_names)
     for el in array:
-        bins_val[_times(el - minn, step)] += 1
+        bins_val[min(int((el - minn) / step), bins - 1)] += 1
     return bins_val, bins_names
